==> r-cran-ggsci_2.8.orig.tar.gz: ggsci/README.md <==
# ggsci  <a href="https://ggsci.net"><img src="https://i.imgur.com/pGwTPP5.png" align="right" alt="logo" height="180" width="180" /></a>

[![Build Status](https://travis-ci.org/road2stat/ggsci.svg?branch=master)](https://travis-ci.org/road2stat/ggsci)
[![AppVeyor Build Status](https://ci.appveyor.com/api/projects/status/github/road2stat/ggsci?branch=master&svg=true)](https://ci.appveyor.com/project/road2stat/ggsci)
[![CRAN Version](https://www.r-pkg.org/badges/version/ggsci)](https://cran.r-project.org/package=ggsci)
[![Downloads from the RStudio CRAN mirror](https://cranlogs.r-pkg.org/badges/ggsci)](https://cran.r-project.org/package=ggsci)

`ggsci` offers a collection of `ggplot2` color palettes inspired by scientific journals, data visualization libraries, science fiction movies, and TV shows.

## Installation

Install `ggsci` from CRAN:

```r
install.packages("ggsci")
```

Or try the development version on GitHub:

```r
# install.packages("devtools")
devtools::install_github("road2stat/ggsci")
```

[Browse the vignette](https://ggsci.net/articles/ggsci.html) (or open with `vignette("ggsci")` in R) for a quick-start guide.

## Gallery

### NPG

<img src="https://i.imgur.com/ZjCm5ng.png" width="100%" alt="npg">

### AAAS

<img src="https://i.imgur.com/Wt8z0Xs.png" width="100%" alt="aaas">

### NEJM

<img src="https://i.imgur.com/WXREdrP.png" width="100%" alt="nejm">

### Lancet

<img src="https://i.imgur.com/5b01l68.png" width="100%" alt="lancet">

### JAMA

<img src="https://i.imgur.com/dmZO9e5.png" width="100%" alt="jama">

### JCO

<img src="https://i.imgur.com/3t8Q1kF.png" width="100%" alt="jco">

### UCSCGB

<img src="https://i.imgur.com/6HTPa1B.png" width="100%" alt="ucscgb">

### D3

<img src="https://i.imgur.com/mKhrUyT.png" width="100%" alt="d3">

### LocusZoom

<img src="https://i.imgur.com/JqdxnuF.png" width="100%" alt="locuszoom">

### IGV

<img src="https://i.imgur.com/bLB8Ofe.png" width="100%" alt="igv">

### UChicago

<img src="https://i.imgur.com/Eb8agLj.png" width="100%" alt="uchicago">

### Star Trek

<img src="https://i.imgur.com/HYs7OzD.png" width="100%" alt="startrek">

### Tron Legacy

<img src="https://i.imgur.com/RrF3kp3.png" width="100%" alt="tron">

### Futurama

<img src="https://i.imgur.com/IeBjLy7.png" width="100%" alt="futurama">

### Rick and Morty

<img src="https://i.imgur.com/8zKuCPz.png" width="100%" alt="rickandmorty">

### The Simpsons

<img src="https://i.imgur.com/zBqZjpX.png" width="100%" alt="simpsons">

### GSEA

<img src="https://i.imgur.com/20vxsS9.png" width="100%" alt="gsea">

### Material Design

<img src="https://i.imgur.com/W2lVixt.png" width="92%" alt="material">

## Contribute

To contribute to this project, please take a look at the [Contributing Guidelines](CONTRIBUTING.md) first. Please note that this project is released with a [Contributor Code of Conduct](CONDUCT.md). By participating in this project you agree to abide by its terms.

==> r-cran-ggsci_2.9.orig.tar.gz: ggsci/README.md <==
# ggsci  <a href="https://nanx.me/ggsci/"><img src="https://i.imgur.com/pGwTPP5.png" align="right" alt="logo" height="180" width="180" /></a>

[![Build Status](https://travis-ci.org/road2stat/ggsci.svg?branch=master)](https://travis-ci.org/road2stat/ggsci)
[![AppVeyor Build Status](https://ci.appveyor.com/api/projects/status/github/road2stat/ggsci?branch=master&svg=true)](https://ci.appveyor.com/project/road2stat/ggsci)
[![CRAN Version](https://www.r-pkg.org/badges/version/ggsci)](https://cran.r-project.org/package=ggsci)
[![Downloads from the RStudio CRAN mirror](https://cranlogs.r-pkg.org/badges/ggsci)](https://cran.r-project.org/package=ggsci)

`ggsci` offers a collection of `ggplot2` color palettes inspired by scientific journals, data visualization libraries, science fiction movies, and TV shows.

## Installation

Install `ggsci` from CRAN:

```r
install.packages("ggsci")
```

Or try the development version on GitHub:

```r
# install.packages("devtools")
devtools::install_github("road2stat/ggsci")
```

[Browse the vignette](https://nanx.me/ggsci/articles/ggsci.html) (or open with `vignette("ggsci")` in R) for a quick-start guide.

## Gallery

### NPG

<img src="https://i.imgur.com/ZjCm5ng.png" width="100%" alt="npg">

### AAAS

<img src="https://i.imgur.com/Wt8z0Xs.png" width="100%" alt="aaas">

### NEJM

<img src="https://i.imgur.com/WXREdrP.png" width="100%" alt="nejm">

### Lancet

<img src="https://i.imgur.com/5b01l68.png" width="100%" alt="lancet">

### JAMA

<img src="https://i.imgur.com/dmZO9e5.png" width="100%" alt="jama">

### JCO

<img src="https://i.imgur.com/3t8Q1kF.png" width="100%" alt="jco">

### UCSCGB

<img src="https://i.imgur.com/6HTPa1B.png" width="100%" alt="ucscgb">

### D3

<img src="https://i.imgur.com/mKhrUyT.png" width="100%" alt="d3">

### LocusZoom

<img src="https://i.imgur.com/JqdxnuF.png" width="100%" alt="locuszoom">

### IGV

<img src="https://i.imgur.com/bLB8Ofe.png" width="100%" alt="igv">

### UChicago

<img src="https://i.imgur.com/Eb8agLj.png" width="100%" alt="uchicago">

### Star Trek

<img src="https://i.imgur.com/HYs7OzD.png" width="100%" alt="startrek">

### Tron Legacy

<img src="https://i.imgur.com/RrF3kp3.png" width="100%" alt="tron">

### Futurama

<img src="https://i.imgur.com/IeBjLy7.png" width="100%" alt="futurama">

### Rick and Morty

<img src="https://i.imgur.com/8zKuCPz.png" width="100%" alt="rickandmorty">

### The Simpsons

<img src="https://i.imgur.com/zBqZjpX.png" width="100%" alt="simpsons">

### GSEA

<img src="https://i.imgur.com/20vxsS9.png" width="100%" alt="gsea">

### Material Design

<img src="https://i.imgur.com/W2lVixt.png" width="92%" alt="material">

## Contribute

To contribute to this project, please take a look at the [Contributing Guidelines](CONTRIBUTING.md) first. Please note that this project is released with a [Contributor Code of Conduct](CONDUCT.md). By participating in this project you agree to abide by its terms.
